@@ -1,10 +1,14 @@
-# Copyrights 2003-2016 by [Mark Overmeer <perl@overmeer.net>].
-#  For other contributors see Changes.
+# Copyrights 2003-2020 by [Mark Overmeer <markov@cpan.org>].
+#  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
+# This code is part of distribution User-Identity.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
+
 package User::Identity::Item;
 use vars '$VERSION';
-$VERSION = '0.96';
+$VERSION = '1.00';
 
 
 use strict;
@@ -98,7 +102,6 @@ sub addCollection(@)
     $self->{UI_col}{$object->name} = $object;
 }
 
-#-----------------------------------------
 
 
 sub removeCollection($)
@@ -109,7 +112,6 @@ sub removeCollection($)
     || delete $self->{UI_col}{$name.'s'};
 }
 
-#-----------------------------------------
 
 
 sub collection($;$)
@@ -121,7 +123,6 @@ sub collection($;$)
     wantarray ? $collection->roles : $collection;
 }
 
-#-----------------------------------------
 
 
 sub add($$)
@@ -139,20 +140,6 @@ sub add($$)
     $collection->addRole(@_);
 }
 
-#-----------------------------------------
-
-
-sub find($$)
-{   my $all        = shift->{UI_col};
-    my $collname   = shift;
-    my $collection
-     = ref $collname && $collname->isa('User::Identity::Collect') ? $collname
-     : ($all->{$collname} || $all->{$collname.'s'});
-
-    return () unless defined $collection;
-    $collection->find(shift);
-}
-
 
 sub type { "item" }
 
@@ -173,5 +160,18 @@ sub user()
     defined $parent ? $parent->user : undef;
 }
 
+#-----------------------------------------
+
+
+sub find($$)
+{   my $all        = shift->{UI_col};
+    my $collname   = shift;
+    my $collection
+     = ref $collname && $collname->isa('User::Identity::Collection') ? $collname
+     : ($all->{$collname} || $all->{$collname.'s'});
+
+    defined $collection ? $collection->find(shift) : ();
+}
+
 1;
 
